RDFLib Python binding for OWL Abstract Syntax
=============================================

ORDF contains an modified version of `InfixOWL`_ from `FuXi`.
It is intended to provide some ORM-like facilities without 
going as far as things like `RDFAlchemy`_ or `SuRF`_

This implementation is derived from:

    * http://code.google.com/p/fuxi/source/browse/lib/Syntax/InfixOWL.py

See also:

    * http://www.w3.org/TR/owl-semantics/syntax.html
    * http://owl-workshop.man.ac.uk/acceptedLong/submission_9.pdf

.. _InfixOWL: http://code.google.com/p/fuxi/wiki/InfixOwl
.. _FuXi: http://code.google.com/p/fuxi
.. _RDFAlchemy: http://rdfalchemy.org/
.. _SuRF: http://code.google.com/p/surfrdf

.. automodule:: ordf.vocab.owl